package cn.wise.sc.cement.business.controller;

import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.StrUtil;
import cn.wise.sc.cement.business.entity.NormProduction;
import cn.wise.sc.cement.business.entity.NormProductionStatistics;
import cn.wise.sc.cement.business.model.BaseResponse;
import cn.wise.sc.cement.business.model.PageQuery;
import cn.wise.sc.cement.business.model.vo.NormProductionVo;
import cn.wise.sc.cement.business.model.vo.ProductionVo;
import cn.wise.sc.cement.business.service.INormProductionService;
import cn.wise.sc.cement.business.util.PageUtil;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;

import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.Date;
import java.util.List;

/**
 * <p>
 * 前端控制器
 * </p>
 *
 * @author ztw
 * @since 2020-09-23
 */
@RestController
@Api(tags = "人员产值统计-标准产值")
@RequestMapping("/business/norm/production")
public class NormProductionController {

    final
    INormProductionService iNormProductionService;

    public NormProductionController(INormProductionService iNormProductionService) {
        this.iNormProductionService = iNormProductionService;
    }

    @PostMapping("/create")
    @ApiOperation("新增标准产值配置")
    public BaseResponse<NormProduction> addObj(@RequestBody NormProduction normProduction) {
        return iNormProductionService.addObj(normProduction);
    }

    @GetMapping("/page")
    @ApiOperation("分页查询")
    public BaseResponse<IPage<NormProductionVo>> page(PageQuery pageQuery) {
        return iNormProductionService.getPage(pageQuery);
    }

    @PutMapping("/edit")
    @ApiOperation("编辑标注产值配置")
    public BaseResponse<Boolean> edit(@RequestBody NormProduction production) {
        return iNormProductionService.edit(production);
    }

    @GetMapping("/{id}")
    @ApiOperation("根据id获取标准产值配置")
    public BaseResponse<NormProduction> getById(@PathVariable("id") Integer id) {
        if (id == null || id <= 0) {
            return BaseResponse.errorMsg("id不能为空!");
        }
        NormProduction rts = iNormProductionService.getById(id);

        if (rts != null) {
            return BaseResponse.okData(rts);
        } else {
            return BaseResponse.errorMsg("没找着符合要求的信息!");
        }
    }

    @PutMapping("/status/{id}")
    @ApiOperation("启用/禁用")
    public BaseResponse<Integer> activeOrForbidden(@PathVariable("id") Integer id) {

        if (id == null || id <= 0) {
            return BaseResponse.errorMsg("编号id不能为空!");
        }
        return iNormProductionService.activeOrForbidden(id);
    }

    @GetMapping("/statistics")
    @ApiOperation("标准产值统计")
    public BaseResponse normProductionStatistics(String start, String end, String name, PageQuery pageQuery) {

        Long startTime = null;
        Long endTime = null;
        if (StrUtil.isNotBlank(start) && StrUtil.isNotBlank(end)) {
            startTime = DateUtil.parseDate(start).getTime();
            endTime = DateUtil.parseDate(end).getTime();
        }
        //将list拆分成分页
        BaseResponse<List<NormProductionStatistics>> baseResponse = iNormProductionService
                .normProductionStatistics(startTime, endTime, name);
        if (baseResponse.getCode() == 200) {
            List<NormProductionStatistics> data = baseResponse.getData();
            if (data.size() != 0) {
                Page<NormProductionStatistics> rts = PageUtil.listConvertToPage(data, pageQuery);
                return BaseResponse.okData(rts);
            }
        }
        return baseResponse;
    }

    @GetMapping("/statistics/detail")
    @ApiOperation("标准产值详情")
    public BaseResponse normProductionDetails(Integer userId, String start,
                                              String end, PageQuery pageQuery) {
        Long startTime = null;
        Long endTime = null;
        if (StrUtil.isNotBlank(start) && StrUtil.isNotBlank(end)) {
            startTime = DateUtil.parseDate(start).getTime();
            endTime = DateUtil.parseDate(end).getTime();
        }
        List<NormProduction.NormProductionDetail> data = iNormProductionService.normProductionDetails(userId, startTime, endTime);
        if (data.size() != 0) {
            Page<NormProduction.NormProductionDetail> rts = PageUtil.listConvertToPage(data, pageQuery);
            return BaseResponse.okData(rts);
        }
        return BaseResponse.okData(data);
    }

    @GetMapping("/total/production")
    public BaseResponse production(PageQuery pageQuery, String name, String start, String end) {

        Long startTime = null;
        Long endTime = null;
        if (StrUtil.isNotBlank(start) && StrUtil.isNotBlank(end)) {
            startTime = DateUtil.parseDate(start).getTime();
            endTime = DateUtil.parseDate(end).getTime();
        }

        List<ProductionVo> rts = iNormProductionService.production(name, startTime, endTime);

        return BaseResponse.okData(PageUtil.listConvertToPage(rts, pageQuery));
    }

}

